@@ -1,4 +1,4 @@
-from executorlib._version import get_versions as _get_versions
+from executorlib.executor.base import BaseExecutor
 from executorlib.executor.flux import (
     FluxClusterExecutor,
     FluxJobExecutor,
@@ -10,8 +10,11 @@ from executorlib.executor.slurm import (
 )
 from executorlib.standalone.cache import get_cache_data
 
+from . import _version
+
 __all__: list[str] = [
     "get_cache_data",
+    "BaseExecutor",
     "FluxJobExecutor",
     "FluxClusterExecutor",
     "SingleNodeExecutor",
@@ -19,4 +22,4 @@ __all__: list[str] = [
     "SlurmClusterExecutor",
 ]
 
-__version__ = _get_versions()["version"]
+__version__ = _version.__version__
